<?php

namespace Drupal\bpmn_io\Controller;

use Drupal\Component\Utility\Random;
use Drupal\Component\Uuid\UuidInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Extension\ExtensionPathResolver;
use Drupal\eca\Service\Modellers;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class BpmnIo.
 *
 * @package Drupal\bpmn_io\Controller
 */
class BpmnIo extends ControllerBase {

  /**
   * @var \Drupal\Component\Uuid\UuidInterface
   */
  protected UuidInterface $uuid;

  /**
   * @var \Drupal\eca\Service\Modellers
   */
  protected Modellers $modellerServices;

  /**
   * @var \Drupal\Core\Extension\ExtensionPathResolver
   */
  protected ExtensionPathResolver $extensionPathResolver;

  /**
   * BpmnIo constructor.
   *
   * @param \Drupal\Component\Uuid\UuidInterface $uuid
   * @param \Drupal\eca\Service\Modellers $modeller_services
   * @param \Drupal\Core\Extension\ExtensionPathResolver $extension_path_resolver
   */
  public function __construct(UuidInterface $uuid, Modellers $modeller_services, ExtensionPathResolver $extension_path_resolver) {
    $this->uuid = $uuid;
    $this->modellerServices = $modeller_services;
    $this->extensionPathResolver = $extension_path_resolver;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): BpmnIo {
    return new static(
      $container->get('uuid'),
      $container->get('eca.service.modeller'),
      $container->get('extension.path.resolver')
    );
  }

  /**
   * @return array
   */
  public function add(): array {
    if ($modeller = $this->modellerServices->getModeller('bpmn_io')) {
      $id = $modeller->generateId();
      $emptyBpmn = file_get_contents($this->extensionPathResolver->getPath('module', 'bpmn_io') . '/data/empty.bpmn');
      $emptyBpmn = str_replace([
        'SIDPLACEHOLDER1',
        'SIDPLACEHOLDER2',
        'IDPLACEHOLDER'
      ], [
        'sid-' . $this->uuid->generate(),
        'sid-' . $this->uuid->generate(),
        $id,
      ], $emptyBpmn);
      $modeller->createNewModel($id, $emptyBpmn);
      return $modeller->edit();
    }
    return [];
  }

}
